/*
   DESCCRIO: PROCEDIMENTO PARA VERIFICAR SE  POSSIVEL ENCAIXAR
               A PRODUO DE UM PRODUTO NOS LOTES QUE J FORAM CRIADOS
               NO MRP.
Criao: Welbert G. Moitinha
Data: 25/06/2010

*/

IF EXISTS (SELECT * FROM SYSOBJECTS O, SYSUSERS U
                    WHERE
	        O.NAME = 'VERIFICA_SALDO_LOTE_PROD'  AND
	        TYPE = 'P' 			        AND
	        U.UID = O.UID             		        AND
	        U.NAME = USER)

DROP PROCEDURE VERIFICA_SALDO_LOTE_PROD
GO

CREATE PROCEDURE VERIFICA_SALDO_LOTE_PROD   @P_CDFILIAL VARCHAR(1),
                                            @P_CDPRODUTO VARCHAR(10),
                                            @P_DTMRP DATETIME,
                                            @P_DTPRODUCAO DATETIME,
                                            @P_QTAFABRICDIA DOUBLE PRECISION,
                                            @P_GERACALE  VARCHAR(1) OUTPUT

AS
   DECLARE @V_SALDO DOUBLE PRECISION;
   DECLARE @V_NRSEQLOTEDIA VARCHAR(3);
   DECLARE @V_QTAFABRICDIA DOUBLE PRECISION;
   DECLARE @V_QTAFABRICMRP DOUBLE PRECISION;
   DECLARE @V_QTPADPROCFAB DOUBLE PRECISION;

BEGIN

   SET @V_QTAFABRICDIA = @P_QTAFABRICDIA;
   SET @V_SALDO = 0;


   SELECT @V_SALDO = SUM(ISNULL(C.QTAFABRICMRP,0)) - SUM( ISNULL(C.QTAFABRICDIA,0))
     FROM
          CALEPRODMRP C, PROCFABRICA P
    WHERE
          C.CDFILIAL = @P_CDFILIAL  AND
          C.CDPRODUTO = @P_CDPRODUTO AND
          C.DTPROGPRODCP = @P_DTMRP AND
          CONVERT( DATETIME, C.DTCONCPROMRP, 103) = CONVERT(DATETIME, @P_DTPRODUCAO, 103) AND
          P.CDFILIAL = C.CDFILIAL AND
          P.CDPRODUTO = C.CDPRODUTO AND
          IDPROFABPADR = 'S';


   IF @V_SALDO IS NULL BEGIN
      SET @V_SALDO = 0;
      SET @P_GERACALE = 'S';
   END;


   IF (@V_SALDO >= @V_QTAFABRICDIA) BEGIN

      DECLARE C_REG CURSOR FOR
                       SELECT
                            C.NRSEQLOTEDIA,
                            C.QTAFABRICDIA,
                            C.QTAFABRICMRP,
                            P.QTPADPROCFAB
                         FROM
                            CALEPRODMRP C, PROCFABRICA P
                         WHERE
                            C.CDFILIAL = @P_CDFILIAL  AND
                            C.CDPRODUTO = @P_CDPRODUTO AND
                            C.DTPROGPRODCP = @P_DTMRP AND
                            C.DTCONCPROMRP = @P_DTPRODUCAO AND
                            P.CDFILIAL = C.CDFILIAL AND
                            P.CDPRODUTO = C.CDPRODUTO AND
                            IDPROFABPADR = 'S';


      OPEN C_REG;
      FETCH NEXT FROM C_REG INTO  @V_NRSEQLOTEDIA, @V_QTAFABRICDIA, @V_QTAFABRICMRP, @V_QTPADPROCFAB;

      WHILE (@@FETCH_STATUS = 0) BEGIN

         IF ((@V_QTAFABRICMRP - @V_QTAFABRICDIA) >= @V_QTAFABRICDIA)AND (@V_QTAFABRICDIA > 0) BEGIN

            UPDATE CALEPRODMRP
            SET QTAFABRICDIA = QTAFABRICDIA + @V_QTAFABRICDIA
            WHERE
               (CDFILIAL     = @P_CDFILIAL)             AND
               (DTPROGPRODCP = @P_DTMRP)                AND
               (CDPRODUTO    = @P_CDPRODUTO)  AND
               (DTCONCPROMRP = @P_DTPRODUCAO) AND
               (NRSEQLOTEDIA = @V_NRSEQLOTEDIA);
            SET @V_QTAFABRICDIA = 0;
         END;

         FETCH NEXT FROM C_REG INTO  @V_NRSEQLOTEDIA, @V_QTAFABRICDIA, @V_QTAFABRICMRP, @V_QTPADPROCFAB;
      END;
      CLOSE C_REG;
      DEALLOCATE C_REG;

      SET @P_GERACALE = 'N';
   END
   ELSE BEGIN
      SET @P_GERACALE = 'S';
   END;
END;
GO

-- VERSAO --
EXEC ATUVEROBJ 'VERIFICA_SALDO_LOTE_PROD','4.00.000';
GO

